

//createNode CustomLocator;


#include "Locator.h"
#include <maya/MColor.h>

const MTypeId CustomLocator::typeId( 0x70000 );
const MString CustomLocator::typeName( "CustomLocator" );

//------------------------------------------------------------------------
/// \brief	This function is used to render our custom locator node
/// \param	view	-	the maya viewport to render the locator node in
/// \param	DGpath	-	the DAG path of the object
/// \param	style	-
/// \param	status	-
///
void CustomLocator::draw( M3dView& view,
						  const MDagPath& DGpath,
						  M3dView::DisplayStyle style,
						  M3dView::DisplayStatus status )
{
	MColor col = colorRGB( status );


	// think glPushMatrix()
	view.beginGL();

	// this makes a copy of the current openGL settings so that anything
	// we change will not affect anything else maya draws afterwards.
	glPushAttrib( GL_CURRENT_BIT );

		// draw a red line
		glColor3f(1,0,0);
		glBegin(GL_LINES);
			glVertex3f(  0.0f,-0.5f, 0.0f );
			glVertex3f(  0.0f, 0.5f, 0.0f );
		glEnd();

		// draw yellow quad on xz plane (going to alpha blend it so we can see through it,
		// which i reackon makes it a bit less obtrusive)
		glEnable(GL_BLEND);
		glBlendFunc(GL_SRC_ALPHA,GL_ONE_MINUS_SRC_ALPHA);

		if(status == M3dView::kLead)
			glColor4f(0,1,0,0.3f);
		else
			glColor4f(col.r,col.g,col.b,0.3f);

		glBegin(GL_QUADS);
			glVertex3f( -0.5f, 0.0f, -0.5f );
			glVertex3f(  0.5f, 0.0f, -0.5f );
			glVertex3f(  0.5f, 0.0f,  0.5f );
			glVertex3f( -0.5f, 0.0f,  0.5f );
		glEnd();
		glDisable(GL_BLEND);

	// restore the old openGL settings
	glPopAttrib();

	// think glPopMatrix()
	view.endGL();
}

//------------------------------------------------------------------------
/// \brief	this function can tell maya whether the locator node has a volume
/// \return	true if bounded, false otherwise.
///
bool CustomLocator::isBounded() const
{
	return true;
}

//------------------------------------------------------------------------
/// \brief	returns the bounding box of the locator node
/// \return	the nodes bounding box
///
MBoundingBox CustomLocator::boundingBox() const
{
	MBoundingBox bbox;

	// simply expand the bounding box to contain the points used
	bbox.expand( MPoint( -0.5f, 0.0f, -0.5f ) );
	bbox.expand( MPoint(  0.5f, 0.0f, -0.5f ) );
	bbox.expand( MPoint(  0.5f, 0.0f,  0.5f ) );
	bbox.expand( MPoint( -0.5f, 0.0f,  0.5f ) );
	bbox.expand( MPoint(  0.0f,-0.5f,  0.0f ) );
	bbox.expand( MPoint(  0.0f, 0.5f,  0.0f ) );

	return bbox;
}

//------------------------------------------------------------------------
/// \brief	this function is called by mata to return a new instance of our locator node
/// \return	the new node
///
void* CustomLocator::creator()
{
	return new CustomLocator();
}

//------------------------------------------------------------------------
/// \brief	this function creates a description of our node
/// \return	The status code
///
MStatus CustomLocator::initialize()
{
	return MS::kSuccess;
}
